@@ -490,4 +490,8 @@ class TestWorkerCore:
             output_class=Output,
         )
 
-        assert definition1.input_schema
+        definition2 = Definition.parse_raw(definition1.json())
+
+        assert definition2.source.topic == "in-topic"
+
+        assert definition1 == definition2
